@@ -57,6 +57,11 @@ def uniquer(iterable, key=None):
     """
     Make an iterator that returns each element from iterable only once
     respecting the input order.
+
+    Usage:
+        from pymince.iterator import uniquer
+
+        uniquer([1, 2, 3, 2]) # --> 1 2 3
     """
     getter = key or (lambda x: x)
     bag = set()
@@ -88,7 +93,15 @@ def grouper(iterable, size):
 
 
 def consume(iterator):
-    """Completely consume the given iterator."""
+    """
+    Completely consume the given iterator.
+
+    Usage:
+        from pymince.iterator import consume
+        it = iter([1, 2])
+        consume(it)
+        next(it) # --> StopIteration
+    """
     collections.deque(iterator, maxlen=0)
 
 
@@ -125,7 +138,7 @@ def all_distinct(iterable, key=None):
         all_distinct([1, 2]) # --> True
     """
     grouped = itertools.groupby(iterable, key=key)
-    return all(is_only_one(group) for _, group in grouped)
+    return all(has_only_one(group) for _, group in grouped)
 
 
 def non_empty_or_none(iterator):
@@ -147,12 +160,19 @@ def non_empty_or_none(iterator):
     return itertools.chain((first,), iterator) if first is not empty else None
 
 
-def is_only_one(iterable):
+def has_only_one(iterable):
     """
     Check if given iterable has only one element.
 
     :param iterable:
     :rtype: bool
+
+    Usage:
+        from pymince.iterator import has_only_one
+
+        has_only_one([1]) # --> True
+        has_only_one([1, 2]) # --> False
+        has_only_one([]) # --> False
     """
     flag = object()
     return next(iterable, flag) is not flag and next(iterable, flag) is flag
